<?PHP

/* This 'function' updates the gnucomo database to the correct version it will make changes to the 
 * database. It is called within an if-statement when needed.
 * INPUT      : NONE (everything is available within the class)
 * OUTPUT     : Success TRUE/FALSE 
 * VALUES SET : NONE 
 */

 //Do while statement since all updateshave to be executed starting at the 
 //latest version. It's a walk through.

   switch ($active_version) {
     case 1:
       //DROP the rule that prohibits updates (change of spec).
       $local_sql = "DROP RULE log_update";
       $dbms->query($local_sql);

     case 2:
       //In the log table processed should be false by default
       $local_sql = "UPDATE log SET processed = false";
       $dbms->query($local_sql);

     case 3:
       //In the log_adv a column is added that indicates where the detailed
       //data has been written to
       $local_sql = "ALTER TABLE log_adv ADD COLUMN detailed_table VARCHAR(75)";
       $dbms->query($local_sql);

     case 4:
       //Create a log_adv_kernel_network table that recognizes the log-records
       //that have come from the kernel-network interface (typically iptables).
       $local_sql  = "CREATE TABLE log_adv_kernel_network (";
       $local_sql .= "device_in VARCHAR(15), device_out VARCHAR(15), hw_address  MACADDR, ";
       $local_sql .= "source_ip INET, destination_ip INET, packet_length BIGINT, ";
       $local_sql .= "tos_bit VARCHAR(5), ";
       $local_sql .= "prec_bit VARCHAR(5), ttl INT, header_id BIGINT, source_port INT, ";
       $local_sql .= "destination_port INT, body_length INT, protocol VARCHAR(5), ";
       $local_sql .= "body_len INT";
       $local_sql .= ") INHERITS (log_adv)"; 
       $dbms->query($local_sql);

     case 5:
       //Add the operating system to the object-table
       //COLUMN os (VARCHAR - 25)
       //COLUMN os_version (VARCHAR - 15)
       $local_sql = "ALTER TABLE object ADD COLUMN os TEXT";
       $dbms->query($local_sql);

       $local_sql = "ALTER TABLE object ADD COLUMN os_version TEXT";
       $dbms->query($local_sql);

       $local_sql = "CREATE INDEX os ON object (os)";
       $dbms->query($local_sql);

       $local_sql = "CREATE INDEX os_version ON object (os, os_version)";
       $dbms->query($local_sql);

     case 6:
       //Create a table with supported operating systems. Only after a implementation of a
       //log-processing application a new OS will be added. This ensures the correctness of
       //the entire system.
       $local_sql = "CREATE TABLE supported_os (os_name TEXT, remarks TEXT)";
       $dbms->query($local_sql);

       $local_sql = "CREATE UNIQUE INDEX spp_os ON supported_os (os_name)";
       $dbms->query($local_sql);

     case 7:
       //Create a column in the log table that indicates if the daemon did recognize the 
       //log-record. This makes it easier to trace which log-records still have to be added
       //to the daemon.
       $local_sql = "ALTER TABLE log ADD COLUMN recognized BOOLEAN";
       $dbms->query($local_sql);

       $local_sql = "ALTER TABLE log ALTER COLUMN recognized SET DEFAULT FALSE";
       $dbms->query($local_sql);
  
    case 8: 
       //Set the default value of processed to FALSE
       $local_sql = "ALTER TABLE log ALTER COLUMN processed SET DEFAULT FALSE";
       $dbms->query($local_sql);
      
    case 9:
       $local_sql = "ALTER TABLE log_adv_kernel_network ADD COLUMN window TEXT";
       $dbms->query($local_sql);
 
       $local_sql = "ALTER TABLE log_adv_kernel_network ADD COLUMN urgp INT";
       $dbms->query($local_sql);

       $local_sql = "ALTER TABLE log_adv_kernel_network ADD COLUMN syn BOOLEAN";
       $dbms->query($local_sql);

       $local_sql = "ALTER TABLE log_adv_kernel_network ALTER COLUMN syn SET DEFAULT FALSE";
       $dbms->query($local_sql);

    case 10:

       $local_sql = "ALTER TABLE log_adv_kernel_network ADD COLUMN type INT";
       $dbms->query($local_sql);

       $local_sql = "ALTER TABLE log_adv_kernel_network ADD COLUMN code INT";
       $dbms->query($local_sql);

       $local_sql = "ALTER TABLE log_adv_kernel_network ADD COLUMN sequence_number INT";
       $dbms->query($local_sql);

    case 11:
       $local_sql = "ALTER TABLE log_adv_kernel_network ADD COLUMN res varchar(5)";
       $dbms->query($local_sql);

       $local_sql = "ALTER TABLE log_adv_kernel_network ADD COLUMN rst BOOLEAN";
       $dbms->query($local_sql);

       $local_sql = "ALTER TABLE log_adv_kernel_network ADD COLUMN df BOOLEAN";
       $dbms->query($local_sql);

   case 12:
      $local_sql = "INSERT INTO db_value VALUES ('gcm_daemon_version', '1')";
      $dbms->query($local_sql);	
   }

   $active_version++;
   $local_sql = "UPDATE db_value SET setting_value = ".$active_version." WHERE setting = 'db_version'";
   $dbms->query($local_sql);


?>
